@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2013 Andreas Rönnquist
+ *	Copyright (C) 2011-2015 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -81,6 +81,7 @@ int c_set_skip_pager(lua_State *lua);
 int c_get_window_is_maximized(lua_State *lua);
 int c_get_window_is_maximized_vertically(lua_State *lua);
 int c_get_window_is_maximized_horisontally(lua_State *lua);
+int c_get_window_is_pinned(lua_State *lua);
 
 int c_set_window_fullscreen(lua_State *lua);
 
@@ -114,4 +115,9 @@ int c_focus(lua_State *lua);
 
 int c_get_window_fullscreen(lua_State *lua);
 
+int c_xy(lua_State *lua);
+int c_xywh(lua_State *lua);
+
+int c_on_geometry_changed(lua_State *lua);
+
 #endif /*__HEADER_SCRIPT_FUNCTIONS_*/
