@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2001 Havoc Pennington, 2011-2014 Andreas Rönnquist
+ *	Copyright (C) 2001 Havoc Pennington, 2011-2015 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -26,10 +26,10 @@
 Atom my_wnck_atom_get(const char *atom_name);
 
 void devilspie2_change_state(Screen *screen,
-									Window xwindow,
-									gboolean add,
-									Atom state1,
-									Atom state2);
+                             Window xwindow,
+                             gboolean add,
+                             Atom state1,
+                             Atom state2);
 
 Screen* devilspie2_window_get_xscreen(Window xid);
 
@@ -42,11 +42,11 @@ gboolean undecorate_window(Window xid);
 char* my_wnck_get_string_property_latin1 (Window xwindow, Atom atom);
 
 gboolean my_wnck_get_cardinal_list(Window xwindow,
-												Atom atom,
-												gulong **cardinals,
-												int *len);
+                                   Atom atom,
+                                   gulong **cardinals,
+                                   int *len);
 
-int devilspie2_get_viewport_start(Window xwindow);
+int devilspie2_get_viewport_start(Window xwindow, int *x, int *y);
 
 void my_window_set_window_type(Window xid, gchar *window_type);
 void my_window_set_opacity(Window xid, double value);
